@@ -26,6 +26,18 @@ class Act():
         def __unicode__(self):
             return self.actname
 
+    def reload(self):
+        """Reload the Act, by touching its ini file"""
+        try:
+            with file(self.uwsgifile, 'a'):
+                os.utime(self.uwsgifile, None)
+                print 'updated'
+        except IOError:
+            print 'Could not update, permission denied.'
+            return
+
+
+
     def get_settings(self):
         syspath = sys.path
         sys.path.insert(0,os.path.join(self.venue.VENUE_ROOT,'acts'))
@@ -68,7 +80,7 @@ class Act():
                 return logfile
         return logfile
 
-    def get_uwsgi_port0(self):
+    def get_uwsgi_port(self):
         from backstage.utils import uwsgi_portsniffer
         ip, port = uwsgi_portsniffer.portsniffer(self.uwsgi_log)
         if port is None:
